Struct zx_iob_region_t
Source #[repr(C)]
pub struct zx_iob_region_t {
pub type: zx_iob_region_type_t,
pub access: zx_iob_access_t,
pub size: u64,
pub discipline: zx_iob_discipline_t,
pub extension: zx_iob_region_extension_t,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.