Struct zx_pci_bar_t
Source #[repr(C)]
pub struct zx_pci_bar_t {
pub id: u32,
pub ty: u32,
pub size: usize,
pub zx_pci_bar_union: zx_pci_bar_union,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.